@@ -3,12 +3,16 @@
 
 #pragma once
 
+#include "messagepart.h"
+#include "mimetreeparser_core_export.h"
+
 #include <QAbstractItemModel>
 #include <QModelIndex>
+
 #include <gpgme++/decryptionresult.h>
 #include <gpgme++/key.h>
+#include <gpgme++/verificationresult.h>
 
-#include "mimetreeparser_core_export.h"
 #include <memory>
 
 namespace QGpgME
@@ -50,13 +54,13 @@ public:
         TypeRole = Qt::UserRole + 1,
         ContentRole,
         IsEmbeddedRole,
-        IsEncryptedRole,
-        IsSignedRole,
         IsErrorRole,
-        SecurityLevelRole,
+        SidebarSecurityLevelRole,
         EncryptionSecurityLevelRole,
+        EncryptionIconNameRole,
         SignatureSecurityLevelRole,
-        SignatureDetails,
+        SignatureDetailsRole,
+        SignatureIconNameRole,
         EncryptionDetails,
         ErrorType,
         ErrorString,
@@ -64,11 +68,15 @@ public:
         DateRole,
     };
 
+    /// This enum maps directly to color displayed in the UI for the following elements:
+    /// - Encryption info box
+    /// - Signature info box
+    /// - Sidebar (worse of the two above)
     enum SecurityLevel {
-        Unknow,
-        Good,
-        NotSoGood,
-        Bad,
+        Unknow, ///< Do not display element (not encrypted or not signed)
+        Good, ///< Green
+        NotSoGood, ///< Orange
+        Bad, ////< Red
     };
     Q_ENUM(SecurityLevel);
 
@@ -87,6 +95,9 @@ public:
     [[nodiscard]] bool trimMail() const;
     [[nodiscard]] bool isTrimmed() const;
 
+    static SecurityLevel signatureSecurityLevel(MimeTreeParser::MessagePart *messagePart);
+    static QString signatureDetails(MimeTreeParser::MessagePart *messagePart);
+
 Q_SIGNALS:
     void showHtmlChanged();
     void trimMailChanged();
@@ -111,7 +122,11 @@ class MIMETREEPARSER_CORE_EXPORT SignatureInfo
     Q_PROPERTY(QStringList signerMailAddresses MEMBER signerMailAddresses CONSTANT)
     Q_PROPERTY(bool signatureIsGood MEMBER signatureIsGood CONSTANT)
     Q_PROPERTY(bool isCompliant MEMBER isCompliant CONSTANT)
-    Q_PROPERTY(GpgME::Signature::Validity keyTrust MEMBER keyTrust CONSTANT)
+
+    /// Validity information of the key who signed the message.
+    Q_PROPERTY(QString keyTrust MEMBER keyTrust CONSTANT)
+
+    Q_PROPERTY(GpgME::Signature::Summary signatureSummary MEMBER signatureSummary CONSTANT)
 
 public:
     bool keyRevoked = false;
@@ -121,12 +136,13 @@ public:
     bool crlMissing = false;
     bool crlTooOld = false;
     bool isCompliant = false;
-    GpgME::Signature::Validity keyTrust;
+    QString keyTrust;
     QByteArray keyId;
     const QGpgME::Protocol *cryptoProto = nullptr;
     std::vector<std::pair<GpgME::DecryptionResult::Recipient, GpgME::Key>> decryptRecipients;
 
     QString signer;
+    GpgME::Signature::Summary signatureSummary;
     QStringList signerMailAddresses;
     bool signatureIsGood = false;
 };
